@@ -27,6 +27,7 @@ Handler for "customer order" batches
 from __future__ import unicode_literals, absolute_import, division
 
 import re
+import decimal
 
 import six
 import sqlalchemy as sa
@@ -34,6 +35,7 @@ from sqlalchemy import orm
 
 from rattail.db import model
 from rattail.batch import BatchHandler
+from rattail.util import OrderedDict
 
 
 class CustomerOrderBatchHandler(BatchHandler):
@@ -335,6 +337,17 @@ class CustomerOrderBatchHandler(BatchHandler):
         if cost:
             return cost.case_size
 
+    def get_case_price_for_row(self, row):
+        """
+        Calculate and return the per-case price for the given row.
+
+        NB. we do not store case price, only unit price.  maybe that
+        should change some day..
+        """
+        if row.unit_price is not None:
+            case_price = row.unit_price * (row.case_quantity or 1)
+            return case_price.quantize(decimal.Decimal('0.01'))
+
     # TODO: this method should maybe not exist?  and caller just
     # invokes the handler directly instead?
     def customer_autocomplete(self, session, term, **kwargs):
@@ -398,22 +411,76 @@ class CustomerOrderBatchHandler(BatchHandler):
                                   "{}.custom_product_autocomplete() "
                                   "method.".format(__class__.__name__))
 
+    def get_past_orders(self, batch, **kwargs):
+        """
+        Retrieve a list of past orders for the batch contact.
+        """
+        session = self.app.get_session(batch)
+        model = self.model
+        orders = session.query(model.CustomerOrder)
+
+        contact = self.get_contact(batch)
+        if isinstance(contact, model.Customer):
+            orders = orders.filter(model.CustomerOrder.customer == contact)
+        else:
+            orders = orders.filter(model.CustomerOrder.person == contact)
+
+        orders = orders.order_by(model.CustomerOrder.created.desc())
+        return orders.all()
+
+    def get_past_products(self, batch, **kwargs):
+        """
+        Should return a (possibly empty) list of products which have
+        been ordered in the past by the customer who is associated
+        with the given batch.
+        """
+        session = self.app.get_session(batch)
+        model = self.model
+        products = OrderedDict()
+
+        # track down all order items for batch contact
+        orders = self.get_past_orders(batch)
+        for order in orders:
+            for item in order.items:
+                product = item.product
+                if product:
+                    # we only want the first match for each product
+                    products.setdefault(product.uuid, product)
+
+        return list(products.values())
+
     def get_product_info(self, batch, product, **kwargs):
         """
         Return a data dict containing misc. info pertaining to the
         given product, for the order batch.
         """
         products = self.app.get_products_handler()
+        vendor = product.cost.vendor if product.cost else None
         info = {
             'uuid': product.uuid,
             'upc': six.text_type(product.upc),
             'upc_pretty': product.upc.pretty(),
-            'unit_price_display': products.render_price(product.regular_price),
+            'brand_name': product.brand.name if product.brand else None,
+            'description': product.description,
+            'size': product.size,
             'full_description': product.full_description,
+            'case_quantity': self.app.render_quantity(self.get_case_size_for_product(product)),
+            'unit_price_display': products.render_price(product.regular_price),
+            'department_name': product.department.name if product.department else None,
+            'vendor_name': vendor.name if vendor else None,
+            'url': products.get_url(product),
             'image_url': products.get_image_url(product),
             'uom_choices': self.uom_choices_for_product(product),
         }
 
+        case_price = None
+        if product.regular_price and product.regular_price is not None:
+            case_size = self.get_case_size_for_product(product)
+            case_price = (case_size or 1) * product.regular_price.price
+            case_price = case_price.quantize(decimal.Decimal('0.01'))
+        info['case_price'] = six.text_type(case_price) if case_price is not None else None
+        info['case_price_display'] = self.app.render_currency(case_price)
+
         key = self.config.product_key()
         if key == 'upc':
             info['key'] = info['upc_pretty']
