@@ -58,7 +58,7 @@ class TestFromRattailToRattail(DualRattailTestCase, ImporterTester):
     handler_class = rattail_importing.FromRattailToRattailImport
 
     def test_host_title(self):
-        handler = self.make_handler()
+        handler = self.make_handler(dbkey='host')
         self.assertEqual(handler.host_title, "Rattail (host)")
 
     # TODO
@@ -74,12 +74,6 @@ class TestFromRattailToRattail(DualRattailTestCase, ImporterTester):
 
     def test_make_host_session(self):
 
-        # default is 'host'
-        handler = self.make_handler()
-        session = handler.make_host_session()
-        self.assertIsInstance(session, SessionBase)
-        self.assertIs(session.bind, self.host_engine)
-
         # invalid dbkey
         handler = self.make_handler(dbkey='other')
         self.assertRaises(KeyError, handler.make_host_session)
